sqltriples.Negation

Module sqltriples :: Class Negation |
[show private | hide private]
[frames | no frames]

## Class Negation

    Query --+
            |
           Negation

Method Summary
| `__init__(self, store, result)`
| ``get_child_query`(self, index)` Obtain the query clause and values (as a 2-tuple) which links this object's query to a parent query.
| `get_subquery(self, parent_index, index)`
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`

Method Details

### get_child_query(self, index) Obtain the query clause and values (as a 2-tuple) which links this object's query to a parent query. Employ the given 'index' to correctly qualify the clause's "exposed" columns. Overrides: `sqltriples.Query.get_child_query` (inherited documentation)

Generated by Epydoc 2.1 on Fri Mar 31 17:48:37 2006 | http://epydoc.sf.net